import 'package:cloud_firestore/cloud_firestore.dart';
import 'package:equatable/equatable.dart';

class PendienteEntity extends Equatable {
  final String uuid;
  final DateTime fecha;
  final bool activo;
  final String usuarioUid;
  final String tipo;
  final int puertas;
  final List<dynamic> caravanasPendientes;

  PendienteEntity(this.uuid,
    this.fecha,
    this.activo,
    this.tipo,
    this.puertas,
    this.caravanasPendientes,
    this.usuarioUid
  );

  Map<String, Object> toJson() {
    return {
      'activo': this.activo,
      'fecha': this.fecha,
      'usuarioUid': this.usuarioUid,
      'puertas': this.puertas,
      'caravanasPendientes': this.caravanasPendientes,
    };
  }


  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
          super == other &&
              other is PendienteEntity &&
              runtimeType == other.runtimeType &&
              uuid == other.uuid &&
              fecha == other.fecha &&
              activo == other.activo &&
              usuarioUid == other.usuarioUid &&
              tipo == other.tipo &&
              puertas == other.puertas &&
              caravanasPendientes == other.caravanasPendientes;

  @override
  int get hashCode =>
      super.hashCode ^
      uuid.hashCode ^
      fecha.hashCode ^
      activo.hashCode ^
      usuarioUid.hashCode ^
      tipo.hashCode ^
      puertas.hashCode ^
      caravanasPendientes.hashCode;

  @override
  String toString() {
    return 'PendienteEntity{uuid: $uuid, fecha: $fecha, activo: $activo, usuairoUid: $usuarioUid, tipo: $tipo, puertas: $puertas, caravanasPendientes: $caravanasPendientes}';
  }

  static PendienteEntity fromJson(Map<String, Object> json) {
    return PendienteEntity(
      json["uuid"] as String,
      json["fecha"] as DateTime,
      json["activo"] as bool,
      json["tipo"] as String,
      json["puertas"] as int,
      json["caravanasPendietes"] as List<dynamic>,
      json["usuarioUid"] as String
    );
  }

  static PendienteEntity fromSnapshot(DocumentSnapshot snap) {
    return PendienteEntity(
      snap.documentID,
      snap.data['fecha'].toDate(),
      snap.data['activo'],
      snap.data['tipo'],
      snap.data['puertas'],
      snap.data['caravanasPendientes'],
      snap.data['usuarioUid'],
    );
  }


  Map<String, Object> toDocument() {
    return {
      "fecha": fecha,
      "activo": activo,
      "tipo": tipo,
      "puertas": puertas,
      "caravanasPendientes": caravanasPendientes,
      "usuarioUid": usuarioUid
    };
  }
}
