import 'package:cloud_firestore/cloud_firestore.dart';
import 'package:equatable/equatable.dart';

class ProductoEntity extends Equatable {
  final String uuid;
  final String nombre;
  final bool activo;
  final double precio;
  final double calcio;
  final double fdn;
  final DateTime fecha;
  final double fosforo;
  final double materia;
  final double mcal;
  final double prot;
  final int minimo;
  final int stock;

  ProductoEntity(
      this.uuid,
      this.nombre,
      this.activo,
      this.precio,
      this.calcio,
      this.fdn,
      this.fecha,
      this.fosforo,
      this.materia,
      this.mcal,
      this.prot,
      this.minimo,
      this.stock);

  Map<String, Object> toJson() {
    return {
      'nombre': this.nombre,
      'activo': this.activo,
      'precio': this.precio,
      'calcio': this.calcio,
      'fdn': this.fdn,
      'fecha': this.fecha,
      'fosforo': this.fosforo,
      'materia': this.materia,
      'mcal': this.mcal,
      'prot': this.prot,
      'minimo': this.minimo,
      'stock': this.stock
    };
  }

  @override
  String toString() {
    return 'ProductoEntity{uuid: $uuid, nombre: $nombre, activo: $activo, precio: $precio, calcio: $calcio, fdn: $fdn, fecha: $fecha, fosforo: $fosforo, materia: $materia, mcal: $mcal, prot: $prot, minimo: $minimo, stock: $stock}';
  }

  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
      super == other &&
          other is ProductoEntity &&
          runtimeType == other.runtimeType &&
          uuid == other.uuid &&
          nombre == other.nombre &&
          activo == other.activo &&
          precio == other.precio &&
          calcio == other.calcio &&
          fdn == other.fdn &&
          fecha == other.fecha &&
          fosforo == other.fosforo &&
          materia == other.materia &&
          mcal == other.mcal &&
          prot == other.prot &&
          minimo == other.minimo &&
          stock == other.stock;

  @override
  int get hashCode =>
      super.hashCode ^
      uuid.hashCode ^
      nombre.hashCode ^
      activo.hashCode ^
      precio.hashCode ^
      calcio.hashCode ^
      fdn.hashCode ^
      fecha.hashCode ^
      fosforo.hashCode ^
      materia.hashCode ^
      mcal.hashCode ^
      prot.hashCode ^
      minimo.hashCode ^
      stock.hashCode;

  static ProductoEntity fromJson(Map<String, Object> json) {
    return ProductoEntity(
        json['uuid'] as String,
        json['nombre'] as String,
        json['activo'] as bool,
        json['precio'] as double,
        json['calcio'] as double,
        json['fdn'] as double,
        json['fecha'] as DateTime,
        json['fosforo'] as double,
        json['materia'] as double,
        json['mcal'] as double,
        json['prot'] as double,
        json['minimo'] as int,
        json['stock'] as int);
  }

  static ProductoEntity fromSnapshot(DocumentSnapshot snapshot) {
    return ProductoEntity(
      snapshot.documentID,
      snapshot.data['nombre'],
      snapshot.data['activo'],
      double.parse(snapshot.data['precio'].toString()),
    double.parse(snapshot.data['calcio'].toString()),
      double.parse(snapshot.data['fdn'].toString()),
      snapshot.data['fecha'].toDate() ?? DateTime.now(),
      double.parse(snapshot.data['fosforo'].toString()),
    double.parse(snapshot.data['materia'].toString()),
    double.parse(snapshot.data['mcal'].toString()),
      double.parse(snapshot.data['prot'].toString()),
      snapshot.data['minimo'],
      snapshot.data['stock'],
    );
  }

  Map<String, Object> toDocument() {
    return {
      'nombre': this.nombre,
      'activo': this.activo,
      'precio': this.precio,
      'calcio': this.calcio,
      'fdn': this.fdn,
      'fecha': this.fecha,
      'fosforo': this.fosforo,
      'materia': this.materia,
      'mcal': this.mcal,
      'prot': this.prot,
      'minimo': this.minimo,
      'stock': this.stock
    };
  }
}
