import 'dart:async';

import 'package:meta/meta.dart';
import 'package:cloud_firestore/cloud_firestore.dart';
import '../firebase_repository.dart';
import 'detalles_repository.dart';
import 'entities/entities.dart';

class FirebaseDetallesRepository implements DetallesRepository {
  CollectionReference detallesCollection;
  String empresaId;
  String dietaId;

  FirebaseDetallesRepository(
      {@required String empresaId, String dietaId}) {
    this.detallesCollection = Firestore.instance
        .collection('empresas')
        .document(empresaId)
        .collection("dietas")
        .document(dietaId)
        .collection('detalles');
  }

  @override
  Future<void> addNewDetalle(Detalle detalle) {
    return detallesCollection.add(detalle.toEntity().toDocument());
  }

  @override
  Future<void> deleteDetalle(Detalle detalle) async {
    return detallesCollection.document(detalle.uuid).delete();
  }

  @override
  Stream<List<Detalle>> detalles() {
    return detallesCollection.orderBy("orden").snapshots().map((snapshot) {
      print(snapshot);
      return snapshot.documents
          .map((doc) => Detalle.fromEntity(DetalleEntity.fromSnapshot(doc, this.dietaId))).toList();
    });
  }

  @override
  Future<void> updateDetalle(Detalle update) {
    return detallesCollection
        .document(update.uuid)
        .updateData(update.toEntity().toDocument());
  }


}
